[![Documentation Status](https://readthedocs.org/projects/pyfresco/badge/?version=latest)](https://pyfresco.readthedocs.io/en/latest/)

# pyFRESCO

A Python package for hyperspectral data analysis and processing. Tailored onto the Map-projected Target Reduced Data Products (MTRDR) of the Compact Reconnaissance Imager Spectrometer for Mars (CRISM).

## Features

 - RGB maps: possibility to create RGB maps from spectral paramters datacube
 - Spectra Extraction: three different means of spectra extraction from the CRISM datacube
 - Spectra Normalization: various methods to normalize and pre process the target spectrum
 - Spectra Analysis: Possibility to either make analogue comparisons and/or spectral deconvolution

## Installation

pyFRESCO can be installed using pip:

pip install pyfresco
